package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.IWmshOutboundResultService;
import com.steerinfo.dil.service.impl.WmshGridMaterialServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * WmshOutboundResult RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-10 03:14
 * 类描述
 * 修订历史：
 * 日期：2021-10-10
 * 作者：generator
 * 参考：
 * 描述：WmshOutboundResult RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/wmshoutboundresults")
public class WmshOutboundResultController extends BaseRESTfulController {

    @Autowired
    IWmshOutboundResultService wmshOutboundResultService;

    @Autowired
    WmshGridMaterialServiceImpl wmshGridMaterialService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @ApiOperation(value="查询所有港存库出库实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(159)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOutBoundResult")
    public RESTfulResult getOutBoundResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize
    ){
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> result = wmshOutboundResultService.getAllResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,result);
        return success(pageList);
    }

    @ApiOperation(value="添加港存库出库实绩")
    @PostMapping("/addResult")
    public RESTfulResult addResult(@RequestBody(required = false) Map<String, Object> map) throws Exception {
        int result = wmshOutboundResultService.addResult(map);
        map.put("status", new BigDecimal(0));
        int i1 = wmshGridMaterialService.updatePortStock(map);
        if (i1 == -1){
            return failed("出库数量大于港存库实时库存");
    }else {
            return success(result);
        }
    }

    @PostMapping("findOutboundDetail")
    @ApiOperation(value = "查询点后批次出库操作详情")
    RESTfulResult findOutboundDetail(@RequestBody Map<String, Object> map) {
        Date now=new Date();
        int hour = now.getHours();
        if(hour >=8 && hour < 18){
            now.setHours(8);
        }else{
            now.setHours(18);
        }
        now.setMinutes(0);
        now.setSeconds(0);
        map.put("time",now);
        return success(wmshOutboundResultService.findOutboundDetail(map));
    }
}
